| calculate_loudness | R Documentation |
Calculates the estimated loudness in sones for a given Speech Intelligibility Index (SII) object.
calculate_loudness(x, ohc_proportion = 0.65)
x |
An object of class |
ohc_proportion |
Outer hair cell loss proportion (default: 0.65). |
Returns a numeric value representing the total loudness in sones.
Mark Shaver
sii.res <- sii(speech=c(50, 40, 40, 30, 20, 0), threshold=rep(0,6), method="octave")
calculate_loudness(sii.res)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.