calculate_loudness_bramslow2004: Calculate Loudness for Cochlear Hearing Loss

View source: R/moore_glasberg.R

calculate_loudness_bramslow2004R Documentation

Calculate Loudness for Cochlear Hearing Loss

Description

Fast excitation pattern estimation based on Chen et al. 2011 (JASA) "A new model for calculating auditory excitation patterns and loudness for cases of cochlear hearing loss." This implements the Moore & Glasberg (2004) excitation model.

Usage

calculate_loudness_bramslow2004(
  inputF,
  inputLdB,
  HLcf = NULL,
  HLohcdB0 = NULL,
  HLihcdB0 = NULL,
  cambin = 0.1,
  flow = 50,
  fhigh = 15000,
  outerearcorrection = "FreeField"
)

Arguments

inputF

Vector of dense input frequency values (Hz, typically 1 Hz spaced)

inputLdB

Vector of input spectrum levels (dB/Hz)

HLcf

Audiogram frequencies

HLohcdB0

OHC loss at audiogram frequencies

HLihcdB0

IHC loss at audiogram frequencies

cambin

Spacing [ERB] between successive auditory filter CFs

flow

Lowest center frequency of an auditory filter

fhigh

Highest center frequency of an auditory filter

outerearcorrection

"FreeField", "PDR10", or "Eardrum"

Value

A list containing Loudness (sones), Excitation, Cams, and CFs.


SII documentation built on Sept. 12, 2026, 5:08 p.m.