| critical | R Documentation |
Tables of constants for ANSI/ASA S3.5-1997 (R2024) Speech Intelligibility Index (SII)
data(critical)
data(equal)
data(onethird)
data(octave)
data(overall.spl)
Each data frames has 6-21 observations and a subset of the following variables:
fiCenter frequency of SII band, Hz
liLower limit of frequency band, Hz
hiUpper limit of frequency band, Hz
DeltaiBand width adjustment, dB
IiBand importance function
normal, raised, loud and
shoutStandard spectrum levels for vocal effort levels "normal", "raised", "loud", and "shout", respectively, dB
XiSpectrum level of internal noise, dB
FiBand importance function (weight)
These data objects provide constant tables 1 – 4 from the ANSI S3.5-1997.
criticalTable 1: Critical band SII procedure constants
equalTable 2:Equally contributing (17 band) critical band SII
onethirdTable 3: One-third octave band SII procedure constants
octaveTable 4: Octave band SII procedure constants
overall.splOverall sound pressure level (SPL) for the for vocal effort levels "normal", "raised", "loud", and "shout", in dB
ANSI/ASA S3.5-1997 (R2024), "American National Standard Methods for Calculation of the Speech Intelligibility Index" American National Standards Institute, New York.
ANSI/ASA S3.5-1997 (R2024), "American National Standard Methods for Calculation of the Speech Intelligibility Index" American National Standards Institute, New York.
data(critical)
critical # show entire table
data(equal)
names(equal)
equal$fi # extract just the frequency band centers
data(onethird)
barplot(onethird$Ii) # plot band importance function (weights)
data(octave)
round(octave, digits=2) # just 2 digits
data(overall.spl)
overall.spl
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.