| calculate_binaural_loudness | R Documentation |
Calculates the total perceived binaural loudness based on the Pieper et al. (2021) and Moore et al. (2016) binaural summation models.
calculate_binaural_loudness(x_left, x_right = NULL, alpha_b = -0.25)
x_left |
An object of class 'SII' for the left ear. |
x_right |
Optional. An object of class 'SII' for the right ear. If NULL, assumes a perfectly symmetric bilateral fitting ('x_left == x_right'). |
alpha_b |
Numeric. The binaural inhibition factor. Default is -0.25, reflecting classical normal-hearing binaural inhibition. |
A numeric value representing the total binaural loudness in Sones.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.