Learn R Programming

SII (version 1.2.4)

calculate_loudness: Calculate Loudness (Sones)

Description

Calculates the estimated loudness in sones for a given Speech Intelligibility Index (SII) object.

Usage

calculate_loudness(x, ohc_proportion = 0.65)

Value

Returns a numeric value representing the total loudness in sones.

Arguments

x

An object of class SII as returned by sii.

ohc_proportion

Outer hair cell loss proportion (default: 0.65).

Author

Mark Shaver

Examples

Run this code
sii.res <- sii(speech=c(50, 40, 40, 30, 20, 0), threshold=rep(0,6), method="octave")
calculate_loudness(sii.res)

Run the code above in your browser using DataLab