powered by
Calculates the estimated loudness in sones for a given Speech Intelligibility Index (SII) object.
calculate_loudness(x, ohc_proportion = 0.65)
Returns a numeric value representing the total loudness in sones.
An object of class SII as returned by sii.
SII
sii
Outer hair cell loss proportion (default: 0.65).
Mark Shaver
sii.res <- sii(speech=c(50, 40, 40, 30, 20, 0), threshold=rep(0,6), method="octave") calculate_loudness(sii.res)
Run the code above in your browser using DataLab