Fast excitation pattern estimation based on Chen et al. 2011 (JASA) "A new model for calculating auditory excitation patterns and loudness for cases of cochlear hearing loss." This implements the Moore & Glasberg (2004) excitation model.
calculate_loudness_bramslow2004(
inputF,
inputLdB,
HLcf = NULL,
HLohcdB0 = NULL,
HLihcdB0 = NULL,
cambin = 0.1,
flow = 50,
fhigh = 15000,
outerearcorrection = "FreeField"
)A list containing Loudness (sones), Excitation, Cams, and CFs.
Vector of dense input frequency values (Hz, typically 1 Hz spaced)
Vector of input spectrum levels (dB/Hz)
Audiogram frequencies
OHC loss at audiogram frequencies
IHC loss at audiogram frequencies
Spacing [ERB] between successive auditory filter CFs
Lowest center frequency of an auditory filter
Highest center frequency of an auditory filter
"FreeField", "PDR10", or "Eardrum"